==> evms_2.3.4.orig.tar.gz: evms-2.3.4/ui/gtk/main_window_cb.h <==
/*
 *
 *   (C) Copyright IBM Corp. 2001, 2004
 *
 *   This program is free software;  you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
 *   the GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program;  if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 * Module: main_window_cb.h
 */

#ifndef EVMS_FRONTEND_H_INCLUDED
#include <frontend.h>
#endif

void on_create_evms_volume_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_create_compatibility_volume_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_create_object_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_create_region_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_create_container_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_create_segment_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_assign_segment_manager_to_storage_object_activate(GtkMenuItem * menuitem,
							  gpointer user_data);

void on_expand_volume_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_expand_object_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_expand_container_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_shrink_volume_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_shrink_object_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_shrink_container_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_delete_volume_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_delete_object_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_delete_container_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_remove_object_from_container_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_remove_segment_manager_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_convert_to_compatibility_volume_menu_item_activate(GtkMenuItem * menuitem,
							   gpointer user_data);

void on_convert_to_evms_volume_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_add_feature_to_volume_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_modify_volume_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_modify_object_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_modify_container_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_view_messages_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_view_log_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_mkfs_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_fsck_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_defrag_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_obliterate_filesystem_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_mount_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_unmount_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_commit_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_exit_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

gboolean on_main_window_delete_event(GtkWidget * widget, GdkEvent * event, gpointer user_data);

void on_beginner_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_experienced_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_web_links_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_about_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_browser_notebook_realize(GtkWidget * widget, gpointer user_data);

void on_plugin_columned_list_realize(GtkWidget * widget, gpointer user_data);

void on_view_volumes_ctree_realize(GtkWidget * widget, gpointer user_data);

void on_view_objects_ctree_realize(GtkWidget * widget, gpointer user_data);

void on_view_feature_objects_ctree_realize(GtkWidget * widget, gpointer user_data);

void on_view_regions_ctree_realize(GtkWidget * widget, gpointer user_data);

void on_view_containers_ctree_realize(GtkWidget * widget, gpointer user_data);

void on_view_segments_ctree_realize(GtkWidget * widget, gpointer user_data);

void on_view_disks_ctree_realize(GtkWidget * widget, gpointer user_data);

gboolean on_view_button_press_event(GtkWidget * widget, GdkEventButton * event, gpointer user_data);

gboolean on_refresh_pixmap_eventbox_button_press_event(GtkWidget * widget, GdkEventButton * event,
						       gpointer user_data);

void set_engine_log_level(GtkMenuItem * menuitem, gpointer user_data);

void set_kernel_log_level(GtkMenuItem * menuitem, gpointer user_data);

void on_engine_log_level_submenu_menu_realize(GtkWidget * widget, gpointer user_data);

void on_kernel_info_level_submenu_menu_realize(GtkWidget * widget, gpointer user_data);

void on_engine_log_level_submenu_menu_map(GtkWidget * widget, gpointer user_data);

void on_kernel_info_level_submenu_menu_map(GtkWidget * widget, gpointer user_data);

void on_actions_menu_item_menu_realize(GtkWidget * widget, gpointer user_data);

gboolean on_view_key_press_event(GtkWidget * widget, GdkEventKey * event, gpointer user_data);

void on_toolbar_commit_button_clicked(GtkButton * button, gpointer user_data);

void on_refresh_button_clicked(GtkButton * button, gpointer user_data);

void on_exit_button_clicked(GtkButton * button, gpointer user_data);

void on_view_ctree_tree_expand(GtkCTree * ctree, GList * node, gpointer user_data);

void on_view_ctree_tree_collapse(GtkCTree * ctree, GList * node, gpointer user_data);

void on_volume_tasks_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_object_tasks_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_container_tasks_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_plugin_tasks_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_move_object_data_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_administer_node_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

==> evms_2.5.2.orig.tar.gz: evms-2.5.2/ui/gtk/main_window_cb.h <==
/*
 *
 *   (C) Copyright IBM Corp. 2001, 2004
 *
 *   This program is free software;  you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
 *   the GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program;  if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 * Module: main_window_cb.h
 */

#ifndef EVMS_FRONTEND_H_INCLUDED
#include <frontend.h>
#endif

void on_create_evms_volume_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_create_compatibility_volume_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_create_object_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_create_region_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_create_container_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_create_segment_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_assign_segment_manager_to_storage_object_activate(GtkMenuItem * menuitem,
							  gpointer user_data);

void on_expand_volume_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_expand_object_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_expand_container_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_shrink_volume_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_shrink_object_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_shrink_container_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_delete_volume_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_delete_object_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_delete_container_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_remove_object_from_container_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_remove_segment_manager_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_convert_to_compatibility_volume_menu_item_activate(GtkMenuItem * menuitem,
							   gpointer user_data);

void on_convert_to_evms_volume_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_activate_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_deactivate_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_add_feature_to_volume_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_modify_volume_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_modify_object_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_modify_container_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_view_messages_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_view_log_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_mkfs_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_fsck_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_obliterate_filesystem_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_mount_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_unmount_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_commit_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_backup_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_exit_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

gboolean on_main_window_delete_event(GtkWidget * widget, GdkEvent * event, gpointer user_data);

void on_beginner_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_experienced_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_web_links_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_about_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_browser_notebook_realize(GtkWidget * widget, gpointer user_data);

void on_plugin_columned_list_realize(GtkWidget * widget, gpointer user_data);

void on_view_volumes_ctree_realize(GtkWidget * widget, gpointer user_data);

void on_view_objects_ctree_realize(GtkWidget * widget, gpointer user_data);

void on_view_feature_objects_ctree_realize(GtkWidget * widget, gpointer user_data);

void on_view_regions_ctree_realize(GtkWidget * widget, gpointer user_data);

void on_view_containers_ctree_realize(GtkWidget * widget, gpointer user_data);

void on_view_segments_ctree_realize(GtkWidget * widget, gpointer user_data);

void on_view_disks_ctree_realize(GtkWidget * widget, gpointer user_data);

gboolean on_view_button_press_event(GtkWidget * widget, GdkEventButton * event, gpointer user_data);

gboolean on_refresh_pixmap_eventbox_button_press_event(GtkWidget * widget, GdkEventButton * event,
						       gpointer user_data);

void set_engine_log_level(GtkMenuItem * menuitem, gpointer user_data);

void set_kernel_log_level(GtkMenuItem * menuitem, gpointer user_data);

void on_engine_log_level_submenu_menu_realize(GtkWidget * widget, gpointer user_data);

void on_kernel_info_level_submenu_menu_realize(GtkWidget * widget, gpointer user_data);

void on_engine_log_level_submenu_menu_map(GtkWidget * widget, gpointer user_data);

void on_kernel_info_level_submenu_menu_map(GtkWidget * widget, gpointer user_data);

void on_actions_menu_item_menu_realize(GtkWidget * widget, gpointer user_data);

gboolean on_view_key_press_event(GtkWidget * widget, GdkEventKey * event, gpointer user_data);

void on_toolbar_commit_button_clicked(GtkButton * button, gpointer user_data);

void on_refresh_button_clicked(GtkButton * button, gpointer user_data);

void on_exit_button_clicked(GtkButton * button, gpointer user_data);

void on_view_ctree_tree_expand(GtkCTree * ctree, GList * node, gpointer user_data);

void on_view_ctree_tree_collapse(GtkCTree * ctree, GList * node, gpointer user_data);

void on_volume_tasks_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_object_tasks_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_container_tasks_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_plugin_tasks_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_move_object_data_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);

void on_administer_node_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data);
